@@ -61,7 +61,7 @@ int open_ping_socket_ipv6()
         /* try non-privileged icmp (works on Mac OSX without privileges, for example) */
         s = socket(AF_INET6, SOCK_DGRAM, proto->p_proto);
         if (s < 0) {
-            errno_crash_and_burn("can't create raw socket (must run as root?)");
+            return -1;
         }
     }
 
